* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3)
  * Modeling: Objectives and Transformation Items (Proj…
